@@ -5,16 +5,16 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base;
+use IO::Compress::Base 2.003 ;
 
-use IO::Compress::Base::Common qw(createSelfTiedObject);
-use IO::Compress::Adapter::Bzip2 ;
+use IO::Compress::Base::Common  2.003 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Bzip2 2.003 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bzip2Error);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $Bzip2Error = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -51,7 +51,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common qw(:Parse);
+    use IO::Compress::Base::Common  2.003 qw(:Parse);
     
     return (
             'BlockSize100K' => [0, 1, Parse_unsigned,  1],
@@ -852,7 +852,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
